==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/template/barnraiser_01/me_reputation.tpl.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_reputation_calculus'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
				<p>
					here
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>


<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_reputation'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
					<?php
					if (isset($statistics['user'])) {
					?>
					<table border="0" cellspacing="0" cellpadding="4">
					<?php
					foreach($statistics['user'] as $key => $i):
					if (isset($lang['statistic']['user'][$i['statistic_type_id']])) {
					?>
					<tr>
						<td>
							<?php echo $lang['statistic']['user'][$i['statistic_type_id']];?><br />
						</td>
						<td>
							<?php echo $i['total'];?><br />
						</td>
					</tr>
					<?php
					}
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/template/barnraiser_01/me_reputation.tpl.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_reputation_calculus'];?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<p>
					coming soon<br />
				</p>
			</div>
		</div>
	</div>
</div>


<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_reputation'];?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
					<?php
					if (isset($statistics['user'])) {
					?>
					<table border="0" cellspacing="0" cellpadding="4">
					<?php
					foreach($statistics['user'] as $key => $i):
					if (isset($lang['statistic']['user'][$i['statistic_type_id']])) {
					?>
					<tr>
						<td>
							<?php echo $lang['statistic']['user'][$i['statistic_type_id']];?><br />
						</td>
						<td>
							<?php echo $i['total'];?><br />
						</td>
					</tr>
					<?php
					}
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
</div>
